summaryrefslogtreecommitdiffstats
path: root/libtdeedu/extdate/extdatetbl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libtdeedu/extdate/extdatetbl.cpp')
-rw-r--r--libtdeedu/extdate/extdatetbl.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/libtdeedu/extdate/extdatetbl.cpp b/libtdeedu/extdate/extdatetbl.cpp
index 78c7c9a8..55458417 100644
--- a/libtdeedu/extdate/extdatetbl.cpp
+++ b/libtdeedu/extdate/extdatetbl.cpp
@@ -124,7 +124,7 @@ ExtDateTable::ExtDateTable(TQWidget *parent, ExtDate date_, const char* name, WF
if(!date_.isValid())
{
kdDebug() << "ExtDateTable ctor: WARNING: Given date is invalid, using current date." << endl;
- date_=ExtDate::currentDate();
+ date_=ExtDate::tqcurrentDate();
}
setFocusPolicy( TQ_StrongFocus );
setNumRows(7); // 6 weeks max + headline
@@ -204,7 +204,7 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
normalday=false;
TQBrush brushTitle();
- TQBrush brushInvertTitle(colorGroup().base());
+ TQBrush brushInvertTitle(tqcolorGroup().base());
TQColor titleColor(isEnabled()?( KGlobalSettings::activeTitleColor() ):( KGlobalSettings::inactiveTitleColor() ) );
TQColor textColor(isEnabled()?( KGlobalSettings::activeTextColor() ):( KGlobalSettings::inactiveTextColor() ) );
if (!normalday)
@@ -221,7 +221,7 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
}
painter->drawText(0, 0, w, h-1, AlignCenter,
d->calendar->weekDayName(daynum, true), -1, &rect);
- painter->setPen(colorGroup().text());
+ painter->setPen(tqcolorGroup().text());
painter->moveTo(0, h-1);
painter->lineTo(w-1, h-1);
// ----- draw the weekday:
@@ -238,7 +238,7 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
// � painting a day of the previous month or
// � painting a day of the following month
// TODO: don't hardcode gray here! Use a color with less contrast to the background than normal text.
- painter->setPen( colorGroup().mid() );
+ painter->setPen( tqcolorGroup().mid() );
// painter->setPen(gray);
} else { // paint a day of the current month
if ( d->useCustomColors )
@@ -263,9 +263,9 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
}
painter->setPen( mode->fgColor );
} else
- painter->setPen(colorGroup().text());
+ painter->setPen(tqcolorGroup().text());
} else //if ( firstWeekDay < 4 ) // <- this doesn' make sense at all!
- painter->setPen(colorGroup().text());
+ painter->setPen(tqcolorGroup().text());
}
pen=painter->pen();
@@ -276,19 +276,19 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
if( ((offset+dy) == (pos+1)) && hasFocus())
{
// draw the currently selected date
- painter->setPen(colorGroup().highlight());
- painter->setBrush(colorGroup().highlight());
- pen=TQPen(colorGroup().highlightedText());
+ painter->setPen(tqcolorGroup().highlight());
+ painter->setBrush(tqcolorGroup().highlight());
+ pen=TQPen(tqcolorGroup().highlightedText());
} else {
painter->setBrush(paletteBackgroundColor());
painter->setPen(paletteBackgroundColor());
-// painter->setBrush(colorGroup().base());
-// painter->setPen(colorGroup().base());
+// painter->setBrush(tqcolorGroup().base());
+// painter->setPen(tqcolorGroup().base());
}
- if ( pCellDate == ExtDate::currentDate() )
+ if ( pCellDate == ExtDate::tqcurrentDate() )
{
- painter->setPen(colorGroup().text());
+ painter->setPen(tqcolorGroup().text());
}
if ( paintRect ) painter->drawRect(0, 0, w, h);
@@ -347,7 +347,7 @@ ExtDateTable::keyPressEvent( TQKeyEvent *e )
setDate(date.addDays(1));
return;
case Key_N:
- setDate(ExtDate::currentDate());
+ setDate(ExtDate::tqcurrentDate());
return;
case Key_Return:
case Key_Enter:
@@ -390,7 +390,7 @@ ExtDateTable::setFontSize(int size)
maxCell.setHeight(TQMAX(maxCell.height(), rect.height()));
}
// ----- compare with a real wide number and add some space:
- rect=metrics.boundingRect(TQString::fromLatin1("88"));
+ rect=metrics.boundingRect(TQString::tqfromLatin1("88"));
maxCell.setWidth(TQMAX(maxCell.width()+2, rect.width()));
maxCell.setHeight(TQMAX(maxCell.height()+4, rect.height()));
}
@@ -519,14 +519,14 @@ void ExtDateTable::focusOutEvent( TQFocusEvent *e )
}
TQSize
-ExtDateTable::sizeHint() const
+ExtDateTable::tqsizeHint() const
{
if(maxCell.height()>0 && maxCell.width()>0)
{
return TQSize(maxCell.width()*numCols()+2*frameWidth(),
(maxCell.height()+2)*numRows()+2*frameWidth());
} else {
- kdDebug() << "ExtDateTable::sizeHint: obscure failure - " << endl;
+ kdDebug() << "ExtDateTable::tqsizeHint: obscure failure - " << endl;
return TQSize(-1, -1);
}
}
@@ -677,7 +677,7 @@ ExtDateInternalMonthPicker::ExtDateInternalMonthPicker
}
TQSize
-ExtDateInternalMonthPicker::sizeHint() const
+ExtDateInternalMonthPicker::tqsizeHint() const
{
return TQSize((max.width()+6)*numCols()+2*frameWidth(),
(max.height()+6)*numRows()+2*frameWidth());
@@ -779,7 +779,7 @@ ExtDateInternalMonthPicker::contentsMouseMoveEvent(TQMouseEvent *e)
updateCell( row, col /*, false */ ); // mark the new active cell
}
}
- if ( tmpRow > -1 ) // repaint the former active cell
+ if ( tmpRow > -1 ) // tqrepaint the former active cell
updateCell( tmpRow, tmpCol /*, true */ );
}
}
@@ -947,7 +947,7 @@ int
KPopupFrame::exec(TQPoint pos)
{
popup(pos);
- repaint();
+ tqrepaint();
tqApp->enter_loop();
hide();
return result;